==> open-cluster-management-observability-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/ObservatoriumConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObservatoriumConfigFluentImpl<A extends ObservatoriumConfigFluent<A>> extends BaseFluent<A> implements ObservatoriumConfigFluent<A>{
  public ObservatoriumConfigFluentImpl() {
  }
  public ObservatoriumConfigFluentImpl(ObservatoriumConfig instance) {
    this.withTenantHeader(instance.getTenantHeader()); 
    this.withWriteEndpoint(instance.getWriteEndpoint()); 
  }
  private String tenantHeader;
  private String writeEndpoint;
  public String getTenantHeader() {
    return this.tenantHeader;
  }
  public A withTenantHeader(String tenantHeader) {
    this.tenantHeader=tenantHeader; return (A) this;
  }
  public Boolean hasTenantHeader() {
    return this.tenantHeader != null;
  }
  public String getWriteEndpoint() {
    return this.writeEndpoint;
  }
  public A withWriteEndpoint(String writeEndpoint) {
    this.writeEndpoint=writeEndpoint; return (A) this;
  }
  public Boolean hasWriteEndpoint() {
    return this.writeEndpoint != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ObservatoriumConfigFluentImpl that = (ObservatoriumConfigFluentImpl) o;
    if (tenantHeader != null ? !tenantHeader.equals(that.tenantHeader) :that.tenantHeader != null) return false;
    if (writeEndpoint != null ? !writeEndpoint.equals(that.writeEndpoint) :that.writeEndpoint != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tenantHeader,  writeEndpoint,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tenantHeader != null) { sb.append("tenantHeader:"); sb.append(tenantHeader + ","); }
    if (writeEndpoint != null) { sb.append("writeEndpoint:"); sb.append(writeEndpoint); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-observability-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterobservabilityoperator/apps/v1beta2/ObservatoriumConfigFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterobservabilityoperator.apps.v1beta2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ObservatoriumConfigFluentImpl<A extends ObservatoriumConfigFluent<A>> extends BaseFluent<A> implements ObservatoriumConfigFluent<A>{
  public ObservatoriumConfigFluentImpl() {
  }
  public ObservatoriumConfigFluentImpl(ObservatoriumConfig instance) {
    if (instance != null) {
      this.withTenantHeader(instance.getTenantHeader());
      this.withWriteEndpoint(instance.getWriteEndpoint());
    }
  }
  private String tenantHeader;
  private String writeEndpoint;
  public String getTenantHeader() {
    return this.tenantHeader;
  }
  public A withTenantHeader(String tenantHeader) {
    this.tenantHeader=tenantHeader; return (A) this;
  }
  public Boolean hasTenantHeader() {
    return this.tenantHeader != null;
  }
  public String getWriteEndpoint() {
    return this.writeEndpoint;
  }
  public A withWriteEndpoint(String writeEndpoint) {
    this.writeEndpoint=writeEndpoint; return (A) this;
  }
  public Boolean hasWriteEndpoint() {
    return this.writeEndpoint != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ObservatoriumConfigFluentImpl that = (ObservatoriumConfigFluentImpl) o;
    if (!java.util.Objects.equals(tenantHeader, that.tenantHeader)) return false;

    if (!java.util.Objects.equals(writeEndpoint, that.writeEndpoint)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tenantHeader,  writeEndpoint,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tenantHeader != null) { sb.append("tenantHeader:"); sb.append(tenantHeader + ","); }
    if (writeEndpoint != null) { sb.append("writeEndpoint:"); sb.append(writeEndpoint); }
    sb.append("}");
    return sb.toString();
  }
  
}
